/*
	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __DalXOpenConnection_h__
#define __DalXOpenConnection_h__

#if defined (_WINDOWS)
#	include <windows.h>
#endif /* !_WINDOWS) */

#include <sqltypes.h>
#include <sql.h>
#include <string>

namespace RfcDal
{
	class DalXOpenConnection
	{
		private:
#if defined (LINUX)
			void* _h;
#elif defined (_WINDOWS)
			HMODULE _h;
#endif /* LINUX */

			SQLRETURN (SQL_API *_SQLAllocConnect )( SQLHENV EnvironmentHandle, SQLHDBC *ConnectionHandle );
			SQLRETURN (SQL_API *_SQLAllocEnv )( SQLHENV *EnvironmentHandle );
			SQLRETURN (SQL_API *_SQLAllocHandle )( SQLSMALLINT HandleType, SQLHANDLE InputHandle, SQLHANDLE *OutputHandle );
			SQLRETURN (SQL_API *_SQLAllocStmt )( SQLHDBC ConnectionHandle, SQLHSTMT *StatementHandle );
			SQLRETURN (SQL_API *_SQLBindCol )( SQLHSTMT StatementHandle, SQLUSMALLINT ColumnNumber, SQLSMALLINT TargetType,
												SQLPOINTER TargetValue, SQLLEN BufferLength, SQLLEN *StrLen_or_Ind );
			SQLRETURN (SQL_API *_SQLBindParam )( SQLHSTMT StatementHandle, SQLUSMALLINT ParameterNumber, SQLSMALLINT ValueType,
												SQLSMALLINT ParameterType, SQLULEN LengthPrecision, SQLSMALLINT ParameterScale,
												SQLPOINTER ParameterValue, SQLLEN *StrLen_or_Ind );
			SQLRETURN (SQL_API *_SQLCancel )( SQLHSTMT StatementHandle );
			SQLRETURN (SQL_API *_SQLCloseCursor )( SQLHSTMT StatementHandle );
			SQLRETURN (SQL_API *_SQLColAttribute )( SQLHSTMT StatementHandle, SQLUSMALLINT ColumnNumber, SQLUSMALLINT FieldIdentifier,
												SQLPOINTER CharacterAttribute, SQLSMALLINT BufferLength, SQLSMALLINT *StringLength,
												SQLPOINTER NumericAttribute /* spec says (SQLPOINTER) not (SQLEN*) - PAH */ );
			SQLRETURN (SQL_API *_SQLColumns )( SQLHSTMT StatementHandle, SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
												SQLCHAR *SchemaName, SQLSMALLINT NameLength2, SQLCHAR *TableName, SQLSMALLINT NameLength3,
												SQLCHAR *ColumnName, SQLSMALLINT NameLength4 );
			SQLRETURN (SQL_API *_SQLConnect )( SQLHDBC ConnectionHandle, SQLCHAR *ServerName, SQLSMALLINT NameLength1, SQLCHAR *UserName,
												SQLSMALLINT NameLength2, SQLCHAR *Authentication, SQLSMALLINT NameLength3 );
			SQLRETURN (SQL_API *_SQLCopyDesc )( SQLHDESC SourceDescHandle, SQLHDESC TargetDescHandle);
			SQLRETURN (SQL_API *_SQLDataSources )( SQLHENV EnvironmentHandle, SQLUSMALLINT Direction, SQLCHAR *ServerName,
												SQLSMALLINT BufferLength1, SQLSMALLINT *NameLength1, SQLCHAR *Description,
												SQLSMALLINT BufferLength2, SQLSMALLINT *NameLength2 );
			SQLRETURN (SQL_API *_SQLDescribeCol )( SQLHSTMT StatementHandle, SQLUSMALLINT ColumnNumber, SQLCHAR *ColumnName,
												SQLSMALLINT BufferLength, SQLSMALLINT *NameLength, SQLSMALLINT *DataType,
												SQLULEN *ColumnSize, SQLSMALLINT *DecimalDigits, SQLSMALLINT *Nullable );
			SQLRETURN (SQL_API *_SQLDisconnect )( SQLHDBC ConnectionHandle );
			SQLRETURN (SQL_API *_SQLEndTran )( SQLSMALLINT HandleType, SQLHANDLE Handle, SQLSMALLINT CompletionType );
			SQLRETURN (SQL_API *_SQLError )( SQLHENV EnvironmentHandle, SQLHDBC ConnectionHandle, SQLHSTMT StatementHandle,
												SQLCHAR *Sqlstate, SQLINTEGER *NativeError, SQLCHAR *MessageText,
												SQLSMALLINT BufferLength, SQLSMALLINT *TextLength );
			SQLRETURN (SQL_API *_SQLExecDirect )( SQLHSTMT StatementHandle, SQLCHAR *StatementText, SQLINTEGER TextLength);
			SQLRETURN (SQL_API *_SQLExecute )( SQLHSTMT StatementHandle );
			SQLRETURN (SQL_API *_SQLFetch )( SQLHSTMT StatementHandle );
			SQLRETURN (SQL_API *_SQLFetchScroll )( SQLHSTMT StatementHandle, SQLSMALLINT FetchOrientation, SQLLEN FetchOffset );
			SQLRETURN (SQL_API *_SQLFreeConnect )( SQLHDBC ConnectionHandle );
			SQLRETURN (SQL_API *_SQLFreeEnv )( SQLHENV EnvironmentHandle );
			SQLRETURN (SQL_API *_SQLFreeHandle )( SQLSMALLINT HandleType, SQLHANDLE Handle );
			SQLRETURN (SQL_API *_SQLFreeStmt )( SQLHSTMT StatementHandle, SQLUSMALLINT Option );
			SQLRETURN (SQL_API *_SQLGetConnectAttr )( SQLHDBC ConnectionHandle, SQLINTEGER Attribute, SQLPOINTER Value,
												SQLINTEGER BufferLength, SQLINTEGER *StringLength );
			SQLRETURN (SQL_API *_SQLGetConnectOption )( SQLHDBC ConnectionHandle, SQLUSMALLINT Option, SQLPOINTER Value );
			SQLRETURN (SQL_API *_SQLGetCursorName )( SQLHSTMT StatementHandle, SQLCHAR *CursorName, SQLSMALLINT BufferLength,
												SQLSMALLINT *NameLength );
			SQLRETURN (SQL_API *_SQLGetData )( SQLHSTMT StatementHandle, SQLUSMALLINT ColumnNumber, SQLSMALLINT TargetType,
												SQLPOINTER TargetValue, SQLLEN BufferLength, SQLLEN *StrLen_or_Ind );
			SQLRETURN (SQL_API *_SQLGetDescField )( SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
												SQLPOINTER Value, SQLINTEGER BufferLength, SQLINTEGER *StringLength );
			SQLRETURN (SQL_API *_SQLGetDescRec )( SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber, SQLCHAR *Name, SQLSMALLINT BufferLength,
												SQLSMALLINT *StringLength, SQLSMALLINT *Type, SQLSMALLINT *SubType, SQLLEN *Length,
												SQLSMALLINT *Precision, SQLSMALLINT *Scale, SQLSMALLINT *Nullable );
			SQLRETURN (SQL_API *_SQLGetDiagField )( SQLSMALLINT HandleType, SQLHANDLE Handle,   SQLSMALLINT RecNumber, SQLSMALLINT DiagIdentifier,
												SQLPOINTER DiagInfo, SQLSMALLINT BufferLength, SQLSMALLINT *StringLength );
			SQLRETURN (SQL_API *_SQLGetDiagRec )( SQLSMALLINT HandleType, SQLHANDLE Handle, SQLSMALLINT RecNumber, SQLCHAR *Sqlstate,
												SQLINTEGER *NativeError, SQLCHAR *MessageText,SQLSMALLINT BufferLength, SQLSMALLINT *TextLength );
			SQLRETURN (SQL_API *_SQLGetEnvAttr )( SQLHENV EnvironmentHandle, SQLINTEGER Attribute, SQLPOINTER Value, SQLINTEGER BufferLength,
												SQLINTEGER *StringLength );
			SQLRETURN (SQL_API *_SQLGetFunctions )( SQLHDBC ConnectionHandle, SQLUSMALLINT FunctionId, SQLUSMALLINT *Supported );
			SQLRETURN (SQL_API *_SQLGetInfo )( SQLHDBC ConnectionHandle, SQLUSMALLINT InfoType, SQLPOINTER InfoValue, SQLSMALLINT BufferLength,
												SQLSMALLINT *StringLength);
			SQLRETURN (SQL_API *_SQLGetStmtAttr )( SQLHSTMT StatementHandle, SQLINTEGER Attribute, SQLPOINTER Value, SQLINTEGER BufferLength,
												SQLINTEGER *StringLength );
			SQLRETURN (SQL_API *_SQLGetStmtOption )( SQLHSTMT StatementHandle, SQLUSMALLINT Option, SQLPOINTER Value );
			SQLRETURN (SQL_API *_SQLGetTypeInfo )( SQLHSTMT StatementHandle, SQLSMALLINT DataType );
			SQLRETURN (SQL_API *_SQLNumResultCols )( SQLHSTMT StatementHandle, SQLSMALLINT *ColumnCount );
			SQLRETURN (SQL_API *_SQLParamData )( SQLHSTMT StatementHandle, SQLPOINTER *Value );
			SQLRETURN (SQL_API *_SQLPrepare )( SQLHSTMT StatementHandle, SQLCHAR *StatementText, SQLINTEGER TextLength );
			SQLRETURN (SQL_API *_SQLPrimaryKeys )( SQLHSTMT StatementHandle, SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
													SQLCHAR *SchemaName, SQLSMALLINT NameLength2, SQLCHAR *TableName, SQLSMALLINT NameLength3);
			SQLRETURN (SQL_API *_SQLPutData )( SQLHSTMT StatementHandle, SQLPOINTER Data, SQLLEN StrLen_or_Ind );
			SQLRETURN (SQL_API *_SQLRowCount )( SQLHSTMT StatementHandle, SQLLEN *RowCount );
			SQLRETURN (SQL_API *_SQLSetConnectAttr )( SQLHDBC ConnectionHandle, SQLINTEGER Attribute, SQLPOINTER Value, SQLINTEGER StringLength );
			SQLRETURN (SQL_API *_SQLSetConnectOption )( SQLHDBC ConnectionHandle, SQLUSMALLINT Option, SQLULEN Value );
			SQLRETURN (SQL_API *_SQLSetCursorName )( SQLHSTMT StatementHandle, SQLCHAR *CursorName, SQLSMALLINT NameLength );
			SQLRETURN (SQL_API *_SQLSetDescField )( SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
												SQLPOINTER Value, SQLINTEGER BufferLength );
			SQLRETURN (SQL_API *_SQLSetDescRec )( SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber, SQLSMALLINT Type, SQLSMALLINT SubType, SQLLEN Length,
												SQLSMALLINT Precision, SQLSMALLINT Scale, SQLPOINTER Data, SQLLEN *StringLength, SQLLEN *Indicator);
			SQLRETURN (SQL_API *_SQLSetEnvAttr )( SQLHENV EnvironmentHandle, SQLINTEGER Attribute, SQLPOINTER Value, SQLINTEGER StringLength );
			SQLRETURN (SQL_API *_SQLSetParam )( SQLHSTMT StatementHandle, SQLUSMALLINT ParameterNumber, SQLSMALLINT ValueType, SQLSMALLINT ParameterType,
												SQLULEN LengthPrecision, SQLSMALLINT ParameterScale, SQLPOINTER ParameterValue, SQLLEN *StrLen_or_Ind );
			SQLRETURN (SQL_API *_SQLSetStmtAttr )( SQLHSTMT StatementHandle, SQLINTEGER Attribute, SQLPOINTER Value, SQLINTEGER StringLength );
			SQLRETURN (SQL_API *_SQLSetStmtOption )( SQLHSTMT StatementHandle, SQLUSMALLINT Option, SQLULEN Value );
			SQLRETURN (SQL_API *_SQLSpecialColumns )( SQLHSTMT StatementHandle, SQLUSMALLINT IdentifierType, SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
												SQLCHAR *SchemaName, SQLSMALLINT NameLength2, SQLCHAR *TableName, SQLSMALLINT NameLength3,
												SQLUSMALLINT Scope, SQLUSMALLINT Nullable );
			SQLRETURN (SQL_API *_SQLStatistics )( SQLHSTMT StatementHandle, SQLCHAR *CatalogName, SQLSMALLINT NameLength1, SQLCHAR *SchemaName,
												SQLSMALLINT NameLength2, SQLCHAR *TableName, SQLSMALLINT NameLength3, SQLUSMALLINT Unique,
												SQLUSMALLINT Reserved );
			SQLRETURN (SQL_API *_SQLTables )( SQLHSTMT StatementHandle, SQLCHAR *CatalogName, SQLSMALLINT NameLength1, SQLCHAR *SchemaName,
												SQLSMALLINT NameLength2, SQLCHAR *TableName, SQLSMALLINT NameLength3, SQLCHAR *TableType,
												SQLSMALLINT NameLength4 );
			SQLRETURN (SQL_API *_SQLTransact )( SQLHENV EnvironmentHandle, SQLHDBC ConnectionHandle, SQLUSMALLINT CompletionType );

		public:
			DalXOpenConnection();
			virtual ~DalXOpenConnection();

			void load( const std::string& strLibrary );
			void unload();

			SQLRETURN SQL_API SQLAllocConnect( SQLHENV EnvironmentHandle, SQLHDBC *ConnectionHandle );
			SQLRETURN SQL_API SQLAllocEnv( SQLHENV *EnvironmentHandle );
			SQLRETURN SQL_API SQLAllocHandle( SQLSMALLINT HandleType, SQLHANDLE InputHandle, SQLHANDLE *OutputHandle );
			SQLRETURN SQL_API SQLAllocStmt( SQLHDBC ConnectionHandle, SQLHSTMT *StatementHandle );
			SQLRETURN SQL_API SQLBindCol( SQLHSTMT StatementHandle, SQLUSMALLINT ColumnNumber, SQLSMALLINT TargetType,
												SQLPOINTER TargetValue, SQLLEN BufferLength, SQLLEN *StrLen_or_Ind );
			SQLRETURN SQL_API SQLBindParam( SQLHSTMT StatementHandle, SQLUSMALLINT ParameterNumber, SQLSMALLINT ValueType,
												SQLSMALLINT ParameterType, SQLULEN LengthPrecision, SQLSMALLINT ParameterScale,
												SQLPOINTER ParameterValue, SQLLEN *StrLen_or_Ind );
			SQLRETURN SQL_API SQLCancel( SQLHSTMT StatementHandle );
			SQLRETURN SQL_API SQLCloseCursor( SQLHSTMT StatementHandle );
			SQLRETURN SQL_API SQLColAttribute( SQLHSTMT StatementHandle, SQLUSMALLINT ColumnNumber, SQLUSMALLINT FieldIdentifier,
												SQLPOINTER CharacterAttribute, SQLSMALLINT BufferLength, SQLSMALLINT *StringLength,
												SQLPOINTER NumericAttribute /* spec says (SQLPOINTER) not (SQLEN*) - PAH */ );
			SQLRETURN SQL_API SQLColumns( SQLHSTMT StatementHandle, SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
												SQLCHAR *SchemaName, SQLSMALLINT NameLength2, SQLCHAR *TableName, SQLSMALLINT NameLength3,
												SQLCHAR *ColumnName, SQLSMALLINT NameLength4 );
			SQLRETURN SQL_API SQLConnect( SQLHDBC ConnectionHandle, SQLCHAR *ServerName, SQLSMALLINT NameLength1, SQLCHAR *UserName,
												SQLSMALLINT NameLength2, SQLCHAR *Authentication, SQLSMALLINT NameLength3 );
			SQLRETURN SQL_API SQLCopyDesc( SQLHDESC SourceDescHandle, SQLHDESC TargetDescHandle);
			SQLRETURN SQL_API SQLDataSources( SQLHENV EnvironmentHandle, SQLUSMALLINT Direction, SQLCHAR *ServerName,
												SQLSMALLINT BufferLength1, SQLSMALLINT *NameLength1, SQLCHAR *Description,
												SQLSMALLINT BufferLength2, SQLSMALLINT *NameLength2 );
			SQLRETURN SQL_API SQLDescribeCol( SQLHSTMT StatementHandle, SQLUSMALLINT ColumnNumber, SQLCHAR *ColumnName,
												SQLSMALLINT BufferLength, SQLSMALLINT *NameLength, SQLSMALLINT *DataType,
												SQLULEN *ColumnSize, SQLSMALLINT *DecimalDigits, SQLSMALLINT *Nullable );
			SQLRETURN SQL_API SQLDisconnect( SQLHDBC ConnectionHandle );
			SQLRETURN SQL_API SQLEndTran( SQLSMALLINT HandleType, SQLHANDLE Handle, SQLSMALLINT CompletionType );
			SQLRETURN SQL_API SQLError( SQLHENV EnvironmentHandle, SQLHDBC ConnectionHandle, SQLHSTMT StatementHandle,
												SQLCHAR *Sqlstate, SQLINTEGER *NativeError, SQLCHAR *MessageText,
												SQLSMALLINT BufferLength, SQLSMALLINT *TextLength );
			SQLRETURN SQL_API SQLExecDirect( SQLHSTMT StatementHandle, SQLCHAR *StatementText, SQLINTEGER TextLength);
			SQLRETURN SQL_API SQLExecute( SQLHSTMT StatementHandle );
			SQLRETURN SQL_API SQLFetch( SQLHSTMT StatementHandle );
			SQLRETURN SQL_API SQLFetchScroll( SQLHSTMT StatementHandle, SQLSMALLINT FetchOrientation, SQLLEN FetchOffset );
			SQLRETURN SQL_API SQLFreeConnect( SQLHDBC ConnectionHandle );
			SQLRETURN SQL_API SQLFreeEnv( SQLHENV EnvironmentHandle );
			SQLRETURN SQL_API SQLFreeHandle( SQLSMALLINT HandleType, SQLHANDLE Handle );
			SQLRETURN SQL_API SQLFreeStmt( SQLHSTMT StatementHandle, SQLUSMALLINT Option );
			SQLRETURN SQL_API SQLGetConnectAttr( SQLHDBC ConnectionHandle, SQLINTEGER Attribute, SQLPOINTER Value,
												SQLINTEGER BufferLength, SQLINTEGER *StringLength );
			SQLRETURN SQL_API SQLGetConnectOption( SQLHDBC ConnectionHandle, SQLUSMALLINT Option, SQLPOINTER Value );
			SQLRETURN SQL_API SQLGetCursorName( SQLHSTMT StatementHandle, SQLCHAR *CursorName, SQLSMALLINT BufferLength,
												SQLSMALLINT *NameLength );
			SQLRETURN SQL_API SQLGetData( SQLHSTMT StatementHandle, SQLUSMALLINT ColumnNumber, SQLSMALLINT TargetType,
												SQLPOINTER TargetValue, SQLLEN BufferLength, SQLLEN *StrLen_or_Ind );
			SQLRETURN SQL_API SQLGetDescField( SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
												SQLPOINTER Value, SQLINTEGER BufferLength, SQLINTEGER *StringLength );
			SQLRETURN SQL_API SQLGetDescRec( SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber, SQLCHAR *Name, SQLSMALLINT BufferLength,
												SQLSMALLINT *StringLength, SQLSMALLINT *Type, SQLSMALLINT *SubType, SQLLEN *Length,
												SQLSMALLINT *Precision, SQLSMALLINT *Scale, SQLSMALLINT *Nullable );
			SQLRETURN SQL_API SQLGetDiagField( SQLSMALLINT HandleType, SQLHANDLE Handle,   SQLSMALLINT RecNumber, SQLSMALLINT DiagIdentifier,
												SQLPOINTER DiagInfo, SQLSMALLINT BufferLength, SQLSMALLINT *StringLength );
			SQLRETURN SQL_API SQLGetDiagRec( SQLSMALLINT HandleType, SQLHANDLE Handle, SQLSMALLINT RecNumber, SQLCHAR *Sqlstate,
												SQLINTEGER *NativeError, SQLCHAR *MessageText,SQLSMALLINT BufferLength, SQLSMALLINT *TextLength );
			SQLRETURN SQL_API SQLGetEnvAttr( SQLHENV EnvironmentHandle, SQLINTEGER Attribute, SQLPOINTER Value, SQLINTEGER BufferLength,
												SQLINTEGER *StringLength );
			SQLRETURN SQL_API SQLGetFunctions( SQLHDBC ConnectionHandle, SQLUSMALLINT FunctionId, SQLUSMALLINT *Supported );
			SQLRETURN SQL_API SQLGetInfo( SQLHDBC ConnectionHandle, SQLUSMALLINT InfoType, SQLPOINTER InfoValue, SQLSMALLINT BufferLength,
												SQLSMALLINT *StringLength);
			SQLRETURN SQL_API SQLGetStmtAttr( SQLHSTMT StatementHandle, SQLINTEGER Attribute, SQLPOINTER Value, SQLINTEGER BufferLength,
												SQLINTEGER *StringLength );
			SQLRETURN SQL_API SQLGetStmtOption( SQLHSTMT StatementHandle, SQLUSMALLINT Option, SQLPOINTER Value );
			SQLRETURN SQL_API SQLGetTypeInfo( SQLHSTMT StatementHandle, SQLSMALLINT DataType );
			SQLRETURN SQL_API SQLNumResultCols( SQLHSTMT StatementHandle, SQLSMALLINT *ColumnCount );
			SQLRETURN SQL_API SQLParamData( SQLHSTMT StatementHandle, SQLPOINTER *Value );
			SQLRETURN SQL_API SQLPrepare( SQLHSTMT StatementHandle, SQLCHAR *StatementText, SQLINTEGER TextLength );
			SQLRETURN SQL_API SQLPrimaryKeys( SQLHSTMT StatementHandle, SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
												SQLCHAR *SchemaName, SQLSMALLINT NameLength2, SQLCHAR *TableName, SQLSMALLINT NameLength3 );
			SQLRETURN SQL_API SQLPutData( SQLHSTMT StatementHandle, SQLPOINTER Data, SQLLEN StrLen_or_Ind );
			SQLRETURN SQL_API SQLRowCount( SQLHSTMT StatementHandle, SQLLEN *RowCount );
			SQLRETURN SQL_API SQLSetConnectAttr( SQLHDBC ConnectionHandle, SQLINTEGER Attribute, SQLPOINTER Value, SQLINTEGER StringLength );
			SQLRETURN SQL_API SQLSetConnectOption( SQLHDBC ConnectionHandle, SQLUSMALLINT Option, SQLULEN Value );
			SQLRETURN SQL_API SQLSetCursorName( SQLHSTMT StatementHandle, SQLCHAR *CursorName, SQLSMALLINT NameLength );
			SQLRETURN SQL_API SQLSetDescField( SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
												SQLPOINTER Value, SQLINTEGER BufferLength );
			SQLRETURN SQL_API SQLSetDescRec( SQLHDESC DescriptorHandle, SQLSMALLINT RecNumber, SQLSMALLINT Type, SQLSMALLINT SubType, SQLLEN Length,
												SQLSMALLINT Precision, SQLSMALLINT Scale, SQLPOINTER Data, SQLLEN *StringLength, SQLLEN *Indicator);
			SQLRETURN SQL_API SQLSetEnvAttr( SQLHENV EnvironmentHandle, SQLINTEGER Attribute, SQLPOINTER Value, SQLINTEGER StringLength );
			SQLRETURN SQL_API SQLSetParam( SQLHSTMT StatementHandle, SQLUSMALLINT ParameterNumber, SQLSMALLINT ValueType, SQLSMALLINT ParameterType,
												SQLULEN LengthPrecision, SQLSMALLINT ParameterScale, SQLPOINTER ParameterValue, SQLLEN *StrLen_or_Ind );
			SQLRETURN SQL_API SQLSetStmtAttr( SQLHSTMT StatementHandle, SQLINTEGER Attribute, SQLPOINTER Value, SQLINTEGER StringLength );
			SQLRETURN SQL_API SQLSetStmtOption( SQLHSTMT StatementHandle, SQLUSMALLINT Option, SQLULEN Value );
			SQLRETURN SQL_API SQLSpecialColumns( SQLHSTMT StatementHandle, SQLUSMALLINT IdentifierType, SQLCHAR *CatalogName, SQLSMALLINT NameLength1,
												SQLCHAR *SchemaName, SQLSMALLINT NameLength2, SQLCHAR *TableName, SQLSMALLINT NameLength3,
												SQLUSMALLINT Scope, SQLUSMALLINT Nullable );
			SQLRETURN SQL_API SQLStatistics( SQLHSTMT StatementHandle, SQLCHAR *CatalogName, SQLSMALLINT NameLength1, SQLCHAR *SchemaName,
												SQLSMALLINT NameLength2, SQLCHAR *TableName, SQLSMALLINT NameLength3, SQLUSMALLINT Unique,
												SQLUSMALLINT Reserved );
			SQLRETURN SQL_API SQLTables( SQLHSTMT StatementHandle, SQLCHAR *CatalogName, SQLSMALLINT NameLength1, SQLCHAR *SchemaName,
												SQLSMALLINT NameLength2, SQLCHAR *TableName, SQLSMALLINT NameLength3, SQLCHAR *TableType,
												SQLSMALLINT NameLength4 );
			SQLRETURN SQL_API SQLTransact( SQLHENV EnvironmentHandle, SQLHDBC ConnectionHandle, SQLUSMALLINT CompletionType );
	};
};

#endif /* !__DalXOpenConnection_h__ */
